%define major 1
%define libname %mklibname varnish %{major}
%define develname %mklibname varnish -d

Summary:	Varnish is a high-performance HTTP accelerator
Name:		varnish
Version:	3.0.3
%define subrel	1
Release:	%mkrel 19
License:	BSD
Group:		System/Servers
URL:		http://www.varnish-cache.org/
Source0:	http://repo.varnish-cache.org/source/varnish-%{version}.tar.gz
Source1:        varnish.service
Source3:        varnishncsa.service
Source4:        varnishlog.service
Source5:	varnish.logrotate
Source6:	default.vcl
Patch0:		varnish.varnishtest_debugflag.patch
Patch1:		varnish-3.0.3-link.patch
Patch2:		varnish-3.0.3-automake-1.13.patch
Patch3:		varnish-3.0.3-CVE-2013-4484.patch
Patch4:		varnish-3.0.3-CVE-2015-8852.patch
BuildRequires:	ncurses-devel
BuildRequires:	libxslt-proc
BuildRequires:	pcre-devel
BuildRequires:	groff
BuildRequires:	jemalloc-devel
# Varnish actually needs gcc installed to work. It uses the C compiler 
# at runtime to compile the VCL configuration files. This is by design.
Requires:	gcc
Requires(post): systemd >= %{systemd_required_version}
Requires(post): util-linux

%description
This is the Varnish high-performance HTTP accelerator. Documentation wiki and
additional information about Varnish is available on the following web site:
http://www.varnish-cache.org/

%package -n	%{libname}
Summary:	Shared libraries for varnish
Group:		System/Libraries

%description -n	%{libname}
Varnish is a high-performance HTTP accelerator.

This package provides the shared libraries for varnish.

%package -n	%{develname}
Summary:	Development headers and libraries for varnish
Group:		Development/C
Requires:	%{libname} = %{version}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
Varnish is a high-performance HTTP accelerator.

This package provides the development files for varnish.

%prep
%setup -q
%patch0 -p1
%patch1 -p0
%patch2 -p0
%patch3 -p0
%patch4 -p1

# Hack to get 32- and 64-bits tests run concurrently on the same build machine
case `uname -m` in
	ppc64 | s390x | x86_64 | sparc64 )
		sed -i '
			s,9001,9011,g;
			s,9080,9090,g;
			s,9081,9091,g;
			s,9082,9092,g;
			s,9180,9190,g;
		' bin/varnishtest/*.c bin/varnishtest/tests/*vtc
		;;
	*)
		;;
esac

mkdir examples
cp bin/varnishd/default.vcl etc/zope-plone.vcl examples

mkdir -p Mandriva
cp %{SOURCE5} Mandriva/varnish.logrotate
cp %{SOURCE6} Mandriva/default.vcl

%build
autoreconf -fi

%configure2_5x \
    --disable-static \
    --localstatedir=/var/lib

# We have to remove rpath - not allowed in Fedora
# (This problem only visible on 64 bit arches)
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g;
	s|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

%make

%install

%makeinstall_std INSTALL="install -p"

install -d %{buildroot}%{_sysconfdir}/varnish
install -d %{buildroot}%{_sysconfdir}/logrotate.d
install -d %{buildroot}/var/lib/varnish
install -d %{buildroot}/var/log/varnish

mkdir -p %{buildroot}%{_unitdir}
install -D -m 0644 %SOURCE1 %{buildroot}%{_unitdir}/varnish.service
install -D -m 0644 %SOURCE3 %{buildroot}%{_unitdir}/varnishncsa.service
install -D -m 0644 %SOURCE4 %{buildroot}%{_unitdir}/varnishlog.service
install -m0644 Mandriva/varnish.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/varnish
install -m0644 Mandriva/default.vcl %{buildroot}%{_sysconfdir}/varnish/default.vcl

# cleanup
find %{buildroot}/%{_libdir}/ -name '*.la' -exec rm -f {} ';'

mkdir -p %{buildroot}%{_tmpfilesdir}
cat <<EOF > %{buildroot}%{_tmpfilesdir}/%{name}.conf
d /run/varnish 0755 varnish varnish
EOF

# Use the new ld.so.conf.d
mkdir -p %buildroot/%_sysconfdir/ld.so.conf.d
pushd %buildroot/%_sysconfdir/ld.so.conf.d
echo "%{_libdir}/varnish" > %name.conf
popd

%pre
getent group varnish >/dev/null || groupadd -r varnish
getent passwd varnish >/dev/null || \
	useradd -r -g varnish -d /var/lib/varnish -s /sbin/nologin \
		-c "Varnish http accelerator user" varnish
exit 0

%post
if [ ! -f %{_sysconfdir}/%{name}/secret ]; then
	uuidgen > %{_sysconfdir}/%{name}/secret
	chown %{name}:adm %{_sysconfdir}/%{name}/secret
	chmod 0660 %{_sysconfdir}/%{name}/secret

	# While not strictly related, we also need to fix storage permissions from
	# older versions and the lack of a secret file is a good indicator
	find /var/lib/%{name}/ -uid 0 -exec chown %{name}:%{name} {} \;
fi
%_tmpfilescreate %{name}
%_post_service %{name} %{name} varnishlog varnishncsa

%preun
%_preun_service %{name} %{name} varnishlog varnishncsa

%files
%doc INSTALL README ChangeLog examples
%config(noreplace) %{_sysconfdir}/logrotate.d/varnish
%dir %{_sysconfdir}/varnish
%config(noreplace) %{_sysconfdir}/varnish/default.vcl
%config(noreplace) %{_sysconfdir}/ld.so.conf.d/*
%{_unitdir}/varnish.service
%{_unitdir}/varnishncsa.service
%{_unitdir}/varnishlog.service
%{_tmpfilesdir}/%{name}.conf
%{_sbindir}/*
%{_bindir}/*
%attr(0755,varnish,varnish) %dir /var/lib/varnish
%attr(0755,varnish,varnish) %dir /var/log/varnish
%{_mandir}/man1/*.1*
%{_mandir}/man7/*.7*
%dir %{_libdir}/varnish
%{_libdir}/varnish/libvarnish.so
%{_libdir}/varnish/libvarnishcompat.so
%{_libdir}/varnish/libvcl.so
%{_libdir}/varnish/libvgz.so
%dir %{_libdir}/varnish/vmods
%{_libdir}/varnish/vmods/libvmod_std.so
%{_mandir}/man3/vmod_std.3*

%files -n %{libname}
%doc LICENSE
%{_libdir}/lib*.so.%{major}*

%files -n %{develname}
%{_libdir}/lib*.so
%dir %{_includedir}/varnish
%{_includedir}/varnish/*.h
%{_libdir}/pkgconfig/*.pc


%changelog
* Fri Apr 22 2016 luigiwalser <luigiwalser> 3.0.3-19.1.mga5
+ Revision: 1005368
- rediff patch from debian to fix CVE-2015-8852

* Wed Oct 29 2014 luigiwalser <luigiwalser> 3.0.3-19.mga5
+ Revision: 794535
- BR jemalloc-devel (requested by oden)

* Wed Oct 15 2014 umeabot <umeabot> 3.0.3-18.mga5
+ Revision: 746109
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.0.3-17.mga5
+ Revision: 690127
- Mageia 5 Mass Rebuild

* Wed Feb 12 2014 colin <colin> 3.0.3-16.mga5
+ Revision: 589808
- Nuke invalid reload option.

* Wed Feb 12 2014 colin <colin> 3.0.3-15.mga5
+ Revision: 589702
- Fix post requires
- Correct permissions on data on upgrade from earlier versions

* Tue Feb 11 2014 colin <colin> 3.0.3-14.mga5
+ Revision: 589450
- Ensure we create the secret file at package install

* Tue Feb 11 2014 colin <colin> 3.0.3-13.mga5
+ Revision: 589442
- Deprecate custom 'params' file in favour of standard systemd dropins/overrides
- Do not daemonize logger (rely on systemd)
- Do not daemonize NCSA logger (rely on systemd)

* Thu Dec 26 2013 luigiwalser <luigiwalser> 3.0.3-12.mga4
+ Revision: 560870
- fix various issues with varnish services (mga#11678)

* Thu Dec 12 2013 luigiwalser <luigiwalser> 3.0.3-11.mga4
+ Revision: 556429
- use standard scriplet macros for services

* Fri Nov 29 2013 oden <oden> 3.0.3-10.mga4
+ Revision: 554069
- sync changes from mbs1 (take 2)
- sync changes from mbs1

* Fri Nov 15 2013 luigiwalser <luigiwalser> 3.0.3-9.mga4
+ Revision: 551436
- add upstream patch to fix CVE-2013-4484

* Sat Oct 19 2013 umeabot <umeabot> 3.0.3-8.mga4
+ Revision: 523271
- Mageia 4 Mass Rebuild

* Wed Apr 03 2013 neoclust <neoclust> 3.0.3-7.mga3
+ Revision: 407529
- Add ld.so.conf.d file to find libs

* Sun Mar 24 2013 colin <colin> 3.0.3-6.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Mon Jan 14 2013 umeabot <umeabot> 3.0.3-5.mga3
+ Revision: 385227
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

  + luigiwalser <luigiwalser>
    - add tmpfiles config for /run/varnish

* Tue Jan 08 2013 fwang <fwang> 3.0.3-4.mga3
+ Revision: 341566
- fix build with automake 1.13

* Sat Dec 01 2012 fwang <fwang> 3.0.3-3.mga3
+ Revision: 323901
- correct module fix

* Sat Dec 01 2012 fwang <fwang> 3.0.3-2.mga3
+ Revision: 323754
- link with dl
- fix la name
- fix linkage
- rebuild for new pcre

* Mon Aug 27 2012 fedya <fedya> 3.0.3-1.mga3
+ Revision: 284610
- version update 3.0.3

* Wed Mar 07 2012 dams <dams> 3.0.2-1.mga2
+ Revision: 220758
- rediff patch
- new version 3.0.2
- clean spec file

* Thu Mar 03 2011 ennael <ennael> 2.1.5-1.mga1
+ Revision: 63094
- clean spec file
- imported package varnish

